@@ -17,7 +17,6 @@ __all__ = [
     "rotate",
     "scale_factor",
     "aligned_with",
-    "orient",
     "almost_zero",
     "almost_unit_length",
     "almost_collinear",
@@ -247,7 +246,7 @@ def angle(v1, v2, look=None, assume_normalized=False, units="deg"):
         input, a `(k,)` array.
     """
     if units not in ["deg", "rad"]:
-        raise ValueError("Unrecognized units {}; expected deg or rad".format(units))
+        raise ValueError(f"Unrecognized units {units}; expected deg or rad")
 
     if look is not None:
         # This is a simple approach. Since this is working in two dimensions,
@@ -327,7 +326,7 @@ def rotate(vector, around_axis, angle, units="deg", assume_normalized=False):
     if units == "deg":
         angle = math.radians(angle)
     elif units != "rad":
-        raise ValueError('Unknown units "{}"; expected "deg" or "rad"'.format(units))
+        raise ValueError(f'Unknown units "{units}"; expected "deg" or "rad"')
 
     cosine = math.cos(angle)
     sine = math.sin(angle)
@@ -408,19 +407,6 @@ def aligned_with(vector, along, reverse=False):
         return vector
 
 
-def orient(vector, along, reverse=False):
-    """
-    Deprecated alias for `aligned_with()`. Will be removed in v2.
-    """
-    import warnings
-
-    warnings.warn(
-        "`vg.orient()` has been deprecated and will be removed in vg 2. Use `vg.aligned_with()` instead.",
-        DeprecationWarning,
-    )
-    return aligned_with(vector, along, reverse=reverse)
-
-
 def almost_zero(v, atol=1e-08):
     """
     Test if v is almost the zero vector.
